@@ -10,9 +10,10 @@ test_that("Can list service accounts", {
     )
   }
 
-  testthat::with_mock(
-    `gargle::gce_metadata_request` = request_mock,
-    expect_equal(service_accounts, list_service_accounts())
+  with_mock(
+    gce_metadata_request = request_mock, {
+      expect_equal(service_accounts, list_service_accounts())
+    }
   )
 })
 
